@@ -1,20 +1,11 @@
-/***************************************************************************
-            filter_sylpheed.h  -  Sylpheed maildir mail import
-                             -------------------
-    begin                : April 07 2005
-   copyright            : (C) 2005 by Danny Kukawka
-   email                : danny.kukawka@web.de
-***************************************************************************/
+/*
+  filtersylpheed.cpp  -  Sylpheed maildir mail import
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-/* Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>                      */
+  SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filtersylpheed.h"
 
@@ -29,10 +20,6 @@ using namespace MailImporter;
 class MailImporter::FilterSylpheedPrivate
 {
 public:
-    FilterSylpheedPrivate()
-    {
-    }
-
     int mImportDirDone = 0;
     int mTotalDir = 0;
 };
@@ -237,7 +224,7 @@ void FilterSylpheed::importFiles(const QString &dirName)
             if (!generatedPath) {
                 _path = defaultInstallPath;
                 QString _tmp = dir.filePath(*mailFile);
-                _tmp = _tmp.remove(_tmp.length() - _mfile.length() - 1, _mfile.length() + 1);
+                _tmp.remove(_tmp.length() - _mfile.length() - 1, _mfile.length() + 1);
                 _path += _tmp.remove(mailDir(), Qt::CaseSensitive);
                 QString _info = _path;
                 filterInfo()->addInfoLogEntry(i18n("Import folder %1...", _info.remove(0, 15)));
