@@ -1,19 +1,10 @@
-/***************************************************************************
-            filter_thunderbird.cxx  -  Thunderbird mail import
-                             -------------------
-    begin                : Januar 26 2005
-    copyright            : (C) 2005 by Danny Kukawka
-    email                : danny.kukawka@web.de
- ***************************************************************************/
+/*
+  filterthunderbird.cpp  -  Thunderbird mail import
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+  SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filterthunderbird.h"
 #include "selectthunderbirdprofilewidget.h"
@@ -293,7 +284,7 @@ void FilterThunderbird::importMBox(const QString &mboxName, const QString &rootD
         filterInfo()->setCurrent(0);
         if (mboxName.length() > 20) {
             QString tmp_info = mboxName;
-            tmp_info = tmp_info.replace(mailDir(), QStringLiteral("../"));
+            tmp_info.replace(mailDir(), QStringLiteral("../"));
             if (tmp_info.contains(QLatin1String(".sbd"))) {
                 tmp_info.remove(QStringLiteral(".sbd"));
             }
@@ -350,8 +341,9 @@ void FilterThunderbird::importMBox(const QString &mboxName, const QString &rootD
                     destFolder.remove(QStringLiteral(".sbd"));
                 }
             }
-
-            importMessage(destFolder, tmp.fileName(), filterInfo()->removeDupMessage());
+            if (!importMessage(destFolder, tmp.fileName(), filterInfo()->removeDupMessage())) {
+                filterInfo()->addErrorLogEntry(i18n("Could not import %1", tmp.fileName()));
+            }
 
             int currentPercentage = (int)(((float)mbox.pos() / filenameInfo.size()) * 100);
             filterInfo()->setCurrent(currentPercentage);
